*******************************************************************************
****** This dofile conducts the welfare analysis and produces the welfare efects table
*******************************************************************************



**** Strategy:

**** First evaluate welfare effects around the emean parameter estimates displayed in the regression table
**** Second, construct confidence intervals using the discussed bootstrap approach




clear all



**** Mean Welfare Effects baseline

use Data\Compiled\datasnl-final.dta



encode state, gen(stateid)

gen statenr=stateid

sort statenr

merge m:1 statenr using Data\Compiled\abadieweights.dta


replace wallall2=1/35 if state=="MA"
replace wallgi2=1/35 if state=="MA"


replace wallall2=0 if wallall2==.



drop if wallall2==0



gen MA_GI=0 

replace MA_GI=1 if state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 



**** Normalize year to 2007

gen yearold=year

replace year=year-2007



*** Period Identfiers


gen during=0

replace during=1 if yearold==2006 | yearold==2007



gen after=0

replace after=1 if yearold>2007


**** Interaction Terms

gen MAafter=after*MA

gen MAduring=during*MA


**** Trends


gen MAyear=MA*year


gen after_year=after*year


gen during_year=during*year


gen after_MA_year=after*year*MA


gen during_MA_year=during*year*MA


sort stateid year

**** get mean estimates

gen mem_mo_ind_rel=.

levelsof state, local(levels) 


foreach l of local levels {

quietly sum mem_mo_ind if yearold>2007 & yearold<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*insurance300post if state=="`l'" 


}
**

by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2



* program drop slopes2

*program define slopes2, rclass

*********** derive chnages in enrollment and post-reform enrollment

 local vars "MAafter MAduring MA after during _cons"

 
 ********** Member Months
 
reg mem_mo_ind_rel MAafter MAduring MA after during if yearold<2011 [aweight=wallall2], cluster(stateid) 

local diffenr=_b[MAafter]


quietly sum mem_mo_ind_rel if yearold<2006 & MA==1

local preenr=r(mean)

 *foreach var of local vars {

		
*local enr`var'=_b[`var']
*return scalar enr`var'=`enr`var''	
		
 *       }


 ********** Claim Expenses
 
gen lgac=log(prov_health_serv_incur_ind_year)

reg lgac MAafter MAduring MA after during if yearold<2011 [aweight=wallall2], cluster(stateid) 

local diffac=_b[MAafter]

quietly sum lgac if yearold<2006 & MA==1

local precosts=r(mean)


 *foreach var of local vars {

		
*local claim`var'=_b[`var']
*return scalar claim`var'=`claim`var''	
		
 *       }

********** Premiums

gen lgprem=log(prem_per_year_ind)
		 
reg lgprem MAafter MAduring MA after during if yearold<2011 [aweight=wallall2], cluster(stateid)

local diffpr=_b[MAafter]

quietly sum lgprem if yearold<2006 & MA==1

local preprem=r(mean)

quietly sum prem_per_year_ind if yearold<2006 & MA==1

local prepremlev=r(mean)





sum(MA) 
local MAmean=r(mean)


foreach penalty in 450 550 650 750 850 950 1050 1150 1250 1350 1450 1550 1650 1750 1850 1950 2050{

gen Wfull=((-`diffac')*(`preenr'+`diffenr'))+(1/2*(`diffpr'+log(1-(`penalty'/`prepremlev')))*`diffenr')+(`preprem'-`precosts')*`diffenr'

*replace Wfull=exp(Prempre)-exp(Prempre-Wfull)

gen Imarkup=`preenr'+(-log(1-(`penalty'/`prepremlev')))*`diffenr'/(`diffac'-(`diffpr'+log(1-(`penalty'/`prepremlev'))))

gen Wnet=(`preprem'-`precosts')*(Imarkup-`preenr')-(`diffac')/`diffenr'*(Imarkup)*(Imarkup-`preenr')+1/2*(`diffpr'+log(1-(`penalty'/`prepremlev')))*(Imarkup-`preenr')^2/`diffenr'


quietly su Wfull

local wfull=r(mean)

quietly su Wnet

local wnet=r(mean)


matrix c1=round(`wfull',0.001)
matrix c3=round(`wnet',0.001)

matrix clev`penalty'=c1,c3

matrix drop c1 c3

drop Wfull Wnet Imarkup

}
***


*** Mean welfare effects GI

 ********** Member Months
 
reg mem_mo_ind_rel MAafter MAduring MA after during if yearold<2011 [aweight=wallgi2], cluster(stateid) 

local diffenr=_b[MAafter]


quietly sum mem_mo_ind_rel if yearold<2006 & MA==1

local preenr=r(mean)







reg lgac MAafter MAduring MA after during if yearold<2011 [aw=wallgi2], cluster(stateid) 

local diffac=_b[MAafter]

quietly sum lgac if yearold<2006 & MA==1

local precosts=r(mean)


********** Premiums


		 
reg lgprem MAafter MAduring MA after during if yearold<2011 [aw=wallgi2], cluster(stateid)

local diffpr=_b[MAafter]

quietly sum lgprem if yearold<2006 & MA==1

local preprem=r(mean)

quietly sum prem_per_year_ind if yearold<2006 & MA==1

local prepremlev=r(mean)


*** post-enrollment



sum(MA) 
local MAmean=r(mean)


foreach penalty in 1250 {

gen Wfull=((-`diffac')*(`preenr'+`diffenr'))+(1/2*(`diffpr'+log(1-(`penalty'/`prepremlev')))*`diffenr')+(`preprem'-`precosts')*`diffenr'

*replace Wfull=exp(Prempre)-exp(Prempre-Wfull)

gen Imarkup=`preenr'+(-log(1-(`penalty'/`prepremlev')))*`diffenr'/(`diffac'-(`diffpr'+log(1-(`penalty'/`prepremlev'))))

gen Wnet=(`preprem'-`precosts')*(Imarkup-`preenr')-(`diffac')/`diffenr'*(Imarkup)*(Imarkup-`preenr')+1/2*(`diffpr'+log(1-(`penalty'/`prepremlev')))*(Imarkup-`preenr')^2/`diffenr'


quietly su Wfull

local wfull=r(mean)

quietly su Wnet

local wnet=r(mean)


matrix c1=round(`wfull',0.001)
matrix c3=round(`wnet',0.001)

matrix clevgi`penalty'=c1,c3

matrix drop c1 c3

drop Wfull Wnet Imarkup

}
***





matrix cfinallev=clev1250\clev450 \clev550 \clev650 \clev750 \clev850  \clev950  \clev1050 \clev1150  \clev1350 \clev1450  \clev1550  \clev1650  \clev1750 \clev1850 \clev1950 \clev2050 \clevgi1250

matrix drop clev1250 clev450 clev550 clev650 clev750 clev850 clev950 clev1050 clev1150 clev1350 clev1450 clev1550 clev1650 clev1750 clev1850 clev1950 clev2050 clevgi1250

clear





******************************************************************************

program define bootreg1, rclass

clear

drop _all

use Data\Compiled\bootstrap-snl.dta

bsample 35 , cluster(clusterid)



*sum MA

***********************************


gen mem_mo_ind_rel=.

levelsof state, local(levels) 

foreach l of local levels {

quietly sum insurance300post if state=="`l'"

local Ihat=r(mean)

disp("`Ihat'")

quietly sum obsnongroup300 if state=="`l'"

local Iobs=r(mean)

disp("`Iobs'")

local Ipost=rbinomial(`Iobs', `Ihat')/`Iobs'

disp("`Ipost'")

quietly sum mem_mo_ind if yearold>2007 & yearold<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*`Ipost' if state=="`l'" 

}
****

by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2



* program drop slopes2

*program define slopes2, rclass

*********** derive chnages in enrollment and post-reform enrollment

 local vars "MAafter MAduring MA after during _cons"

 
 ********** Member Months
 
reg mem_mo_ind_rel MAafter MAduring MA after during if yearold<2011, cluster(stateid) 

local diffenr=_b[MAafter]


quietly sum mem_mo_ind_rel if yearold<2006 & MA==1

local preenr=r(mean)

 foreach var of local vars {

		
local enr`var'=_b[`var']
return scalar enr`var'=`enr`var''	
		
        }


 ********** Claim Expenses
 
gen lgac=log(prov_health_serv_incur_ind_year)

reg lgac MAafter MAduring MA after during if yearold<2011, cluster(stateid) 

local diffac=_b[MAafter]

quietly sum lgac if yearold<2006 & MA==1

local precosts=r(mean)


 foreach var of local vars {

		
local claim`var'=_b[`var']
return scalar claim`var'=`claim`var''	
		
        }

********** Premiums

gen lgprem=log(prem_per_year_ind)
		 
reg lgprem MAafter MAduring MA after during if yearold<2011 , cluster(stateid)

local diffpr=_b[MAafter]

quietly sum lgprem if yearold<2006 & MA==1

local preprem=r(mean)

quietly sum prem_per_year_ind if yearold<2006 & MA==1

local prepremlev=r(mean)



 foreach var of local vars {

		
local prem`var'=_b[`var']
return scalar prem`var'=`prem`var''	
		
        }


*** post-enrollment



sum(MA) 
local MAmean=r(mean)



return scalar ACdiff=`diffac'
return scalar Prdiff=`diffpr'
return scalar Idiff=`diffenr'
return scalar Ipre=`preenr'
return scalar Prempre=`preprem'
return scalar Premprelev=`prepremlev'
return scalar Costspre=`precosts'
return scalar MAmean=`MAmean'


end


clear

set more off

# delimit ;

simulate ACdiff=r(ACdiff) Prdiff=r(Prdiff) Idiff=r(Idiff) Ipre=r(Ipre) Costspre=r(Costspre) Prempre=r(Prempre) Premprelev=r(Premprelev) MAmean=r(MAmean), saving(Data\SNL\bootreg1wel, replace) reps(5000) seed(1111): bootreg1 ;

# delimit cr

drop if MAmean==0

program drop bootreg1 


*** check reverse

gen Wfull=((-ACdiff)*(Ipre+Idiff))+(1/2*(Prdiff+log(1-(1250/Premprelev)))*Idiff)+(Prempre-Costspre)*Idiff
gen Imarkuprev=(Ipre+Idiff)-Idiff*(-log(1-(1250/Premprelev)))/(ACdiff-(Prdiff+log(1-(1250/Premprelev))))
gen Wmarkup=(Prempre-Costspre)*(Imarkuprev-Ipre)-(ACdiff)/Idiff*(Imarkuprev)*(Imarkuprev-Ipre)+1/2*(Prdiff+log(1-(1250/Premprelev)))*(Imarkuprev-Ipre)^2/Idiff
gen Wnet=Wfull-Wmarkup
centile Wnet, centile(0.5 2.5 5 7.5 10 97.5)

gen Wfulllbound=Costspre*Ipre-(Costspre+ACdiff)*(Ipre+Idiff)+ (Prempre+Prdiff+log(1-(1250/Premprelev)))*Idiff

centile Wfulllbound, centile(0.5 2.5 5 7.5 10 95 97.5 99.5)

drop Wfull Wnet Imarkuprev Wfulllbound

foreach penalty in 450 550 650 750 850 950 1050 1150 1250 1350 1450 1550 1650 1750 1850 1950 2050{

gen Wfull=((-ACdiff)*(Ipre+Idiff))+(1/2*(Prdiff+log(1-(`penalty'/Premprelev)))*Idiff)+(Prempre-Costspre)*Idiff


*replace Wfull=exp(Prempre)-exp(Prempre-Wfull)

gen Imarkup=Ipre+(-log(1-(`penalty'/Premprelev)))*Idiff/(ACdiff-(Prdiff+log(1-(`penalty'/Premprelev))))

gen Wnet=(Prempre-Costspre)*(Imarkup-Ipre)-(ACdiff)/Idiff*(Imarkup)*(Imarkup-Ipre)+1/2*(Prdiff+log(1-(`penalty'/Premprelev)))*(Imarkup-Ipre)^2/Idiff

*replace Wnet=exp(Prempre)-exp(Prempre-Wnet)

*quietly centile Wfull, centile(50)

*matrix c1=round(r(c_1),0.001)

quietly centile Wfull, centile(0.5 2.5 5 97.5)

matrix c2=round(r(c_1),0.001) , round(r(c_2),0.001) , round(r(c_3),0.001) , round(r(c_4),0.001)

gen indwfull=0
replace indwfull=1 if Wfull>0
quietly sum indwfull

matrix cfull=round(r(mean),0.001)


*quietly centile Wnet , centile(50)

*matrix c3=round(r(c_1),0.001)

quietly centile Wnet, centile(0.5 2.5 5 97.5)

matrix c4=round(r(c_1),0.001) , round(r(c_2),0.001) , round(r(c_3),0.001) , round(r(c_4),0.001)

gen indwnet=0
replace indwnet=1 if Wnet>0
quietly sum indwnet

matrix cnet=round(r(mean),0.001)


*matrix c`penalty'=c1,c2,c3,c4


matrix c`penalty'=c2,c4,cfull,cnet


*matrix c`penalty'=c2,c4


*matrix drop c1 c2 c3 c4 
matrix drop c2 c4 cfull cnet

drop Wfull Wnet Imarkup indwfull indwnet
}
*****

clear

program define bootreg1gi, rclass

clear

drop _all

use Data\Compiled\bootstrap-snl-gi.dta

bsample 35 , cluster(clusterid)



*sum MA

***********************************


gen mem_mo_ind_rel=.

levelsof state, local(levels) 

foreach l of local levels {

quietly sum insurance300post if state=="`l'"

local Ihat=r(mean)

disp("`Ihat'")

quietly sum obsnongroup300 if state=="`l'"

local Iobs=r(mean)

disp("`Iobs'")

local Ipost=rbinomial(`Iobs', `Ihat')/`Iobs'

disp("`Ipost'")

quietly sum mem_mo_ind if yearold>2007 & yearold<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*`Ipost' if state=="`l'" 

}
****

by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2


*********** derive chnages in enrollment and post-reform enrollment

 local vars "MAafter MAduring MA after during _cons"

 
 ********** Member Months
 
reg mem_mo_ind_rel MAafter MAduring MA after during if yearold<2011, cluster(stateid) 

local diffenr=_b[MAafter]


quietly sum mem_mo_ind_rel if yearold<2006 & MA==1

local preenr=r(mean)

 foreach var of local vars {

		
local enr`var'=_b[`var']
return scalar enr`var'=`enr`var''	
		
        }


 ********** Claim Expenses
 
gen lgac=log(prov_health_serv_incur_ind_year)

reg lgac MAafter MAduring MA after during if yearold<2011, cluster(stateid) 

local diffac=_b[MAafter]

quietly sum lgac if yearold<2006 & MA==1

local precosts=r(mean)


 foreach var of local vars {

		
local claim`var'=_b[`var']
return scalar claim`var'=`claim`var''	
		
        }

********** Premiums

gen lgprem=log(prem_per_year_ind)
		 
reg lgprem MAafter MAduring MA after during if yearold<2011 , cluster(stateid)

local diffpr=_b[MAafter]

quietly sum lgprem if yearold<2006 & MA==1

local preprem=r(mean)

quietly sum prem_per_year_ind if yearold<2006 & MA==1

local prepremlev=r(mean)



 foreach var of local vars {

		
local prem`var'=_b[`var']
return scalar prem`var'=`prem`var''	
		
        }


*** post-enrollment



sum(MA) 
local MAmean=r(mean)



return scalar ACdiff=`diffac'
return scalar Prdiff=`diffpr'
return scalar Idiff=`diffenr'
return scalar Ipre=`preenr'
return scalar Prempre=`preprem'
return scalar Premprelev=`prepremlev'
return scalar Costspre=`precosts'
return scalar MAmean=`MAmean'


end


clear

set more off

# delimit ;

simulate ACdiff=r(ACdiff) Prdiff=r(Prdiff) Idiff=r(Idiff) Ipre=r(Ipre) Costspre=r(Costspre) Prempre=r(Prempre) Premprelev=r(Premprelev) MAmean=r(MAmean), saving(Data\SNL\bootreg1giwel, replace) reps(5000) seed(1111): bootreg1gi ;

# delimit cr

drop if MAmean==0

program drop bootreg1gi 



foreach penalty in 1250 {

gen Wfull=((-ACdiff)*(Ipre+Idiff))+(1/2*(Prdiff+log(1-(`penalty'/Premprelev)))*Idiff)+(Prempre-Costspre)*Idiff


*replace Wfull=exp(Prempre)-exp(Prempre-Wfull)

gen Imarkup=Ipre+(-log(1-(`penalty'/Premprelev)))*Idiff/(ACdiff-(Prdiff+log(1-(`penalty'/Premprelev))))

gen Wnet=(Prempre-Costspre)*(Imarkup-Ipre)-(ACdiff)/Idiff*(Imarkup)*(Imarkup-Ipre)+1/2*(Prdiff+log(1-(`penalty'/Premprelev)))*(Imarkup-Ipre)^2/Idiff

*replace Wnet=exp(Prempre)-exp(Prempre-Wnet)

*quietly centile Wfull, centile(50)

*matrix c1=round(r(c_1),0.001)

quietly centile Wfull, centile(0.5 2.5 5 97.5)

matrix c2=round(r(c_1),0.001) , round(r(c_2),0.001) , round(r(c_3),0.001) , round(r(c_4),0.001)


gen indwfull=0
replace indwfull=1 if Wfull>0
quietly sum indwfull

matrix cfull=round(r(mean),0.001)


*quietly centile Wnet , centile(50)

*matrix c3=round(r(c_1),0.001)

quietly centile Wnet, centile(0.5 2.5 5 97.5)

matrix c4=round(r(c_1),0.001) , round(r(c_2),0.001) , round(r(c_3),0.001) , round(r(c_4),0.001)

*matrix c`penalty'=c1,c2,c3,c4


*matrix drop c1 c2 c3 c4 

gen indwnet=0
replace indwnet=1 if Wnet>0
quietly sum indwnet

matrix cnet=round(r(mean),0.001)

matrix clevgi`penalty'=c2,c4,cfull,cnet

matrix drop c2 c4 cfull cnet

*drop Wfull Wnet Imarkup indwfull indwnet

}
*****





matrix cfinal=c1250\c450 \c550 \c650 \c750 \c850  \c950  \c1050 \c1150  \c1350 \c1450  \c1550  \c1650  \c1750 \c1850 \c1950 \c2050 \clevgi1250

matrix drop c1250 c450 c550 c650 c750 c850 c950 c1050 c1150 c1350 c1450 c1550 c1650 c1750 c1850 c1950 c2050 clevgi1250


clear 

svmat cfinal

svmat cfinallev

**** Add mean estimates

*merge id using welfareests63.dta

*drop cfinal1 cfinal5 id _merge


**** Stars

*tostring cfinal1, 
*tostring cfinal6, 

gen cfinal1str="" 
gen cfinal6str=""


replace cfinal1str=cfinal1str+"$^{*}$" if cfinal3>0 & cfinal2<=0 
replace cfinal1str=cfinal1str+"$^{**}$" if cfinal2>0 & cfinal1<=0
replace cfinal1str=cfinal1str+"$^{***}$" if cfinal1>0

replace cfinal6str=cfinal6str+"$^{*}$" if cfinal7>0 & cfinal6<=0 
replace cfinal6str=cfinal6str+"$^{**}$" if cfinal6>0 & cfinal5<=0
replace cfinal6str=cfinal6str+"$^{***}$" if cfinal5>0

drop  cfinal1 cfinal3 cfinal5  cfinal7

order cfinallev1 cfinal1str cfinal2 cfinal4 cfinal9 cfinallev2 cfinal6str cfinal6 cfinal8  cfinal10 

export excel using Data\Compiled\Tables\bootstrap-welfare, replace
